changeset 1733:4921adb23771 draft

Have chroot-splice.sh copy in native-compiler as well.
author Rob Landley <rob@landley.net>
date Sat, 14 Feb 2015 13:55:53 -0600
parents 156eb9b36245
children fbc625ba4098
files more/chroot-splice.sh
diffstat 1 files changed, 4 insertions(+), 2 deletions(-) [+]
line wrap: on
line diff
--- a/more/chroot-splice.sh	Sat Feb 14 13:53:19 2015 -0600
+++ b/more/chroot-splice.sh	Sat Feb 14 13:55:53 2015 -0600
@@ -11,7 +11,7 @@
 
 # Make sure prerequisites exist
 
-for i in "build/root-filesystem-$1" "$2"
+for i in build/{root-filesystem,native-compiler}-"$1" "$2"
 do
   if [ ! -e "$i" ]
   then
@@ -35,9 +35,11 @@
   more/zapchroot.sh "$CHROOT" || exit 1
 fi
 
 # Copy root filesystem and splice in control image
 cp -lan "build/root-filesystem-$1/." "$CHROOT" || exit 1
+cp -lan "build/native-compiler-$1/." "$CHROOT" || exit 1
 
+# splice in control image
 if [ -d "$2" ]
 then
   mount -o bind "$2" "$CHROOT/mnt" &&
@@ -35,9 +35,11 @@
 fi
 
-# Copy root filesystem and splice in control image
+# Copy root filesystem and native compiler
 cp -lan "build/root-filesystem-$1/." "$CHROOT" || exit 1